.. _signal_analysis.kss:

Karlinska Sleepiness Score (KSS)
================================

.. automodule:: eyetrace.signal_analysis.kss
   :members:
   :undoc-members:
   :show-inheritance:

A placeholder model that combines several metrics (e.g., PERCLOS, blink
frequency, pupil variability) to predict the Karolinska Sleepiness Scale
(1‑9). This function can be replaced with a properly trained model in
future releases.